# tubtools
A collection of scrapers for the TU Berlin web services.
They are mostly intended for purposes of automating reoccurring tasks in teaching at TU Berlin.

Currently the following features are supported:

- Searching students by name, mail or student id on MOSES.
- Downloading assignments from an ISIS course and auto-extracting them.

For convenience two command-line utilities are provided: `isisdl` and `moses-extract`.
